@@ -10,7 +10,7 @@
 # @Pip-Library: https://pypi.org/project/ndn-hydra/
 # ----------------------------------------------------------
 
-import asyncio as aio
+from asyncio import Semaphore
 import logging
 from ndn.app import NDNApp
 from ndn.encoding import FormalName, Component, Name, ContentType
@@ -78,8 +78,8 @@ class HydraFetchClient(object):
 
       # Fetch the rest of the file.
       if start_index <= end_index:
-          semaphore = aio.Semaphore(10)
-          async for (_, _, content, _) in concurrent_fetcher(self.app, name_at_repo, start_index, end_index, semaphore):
+          semaphore = Semaphore(10)
+          async for (_, _, content, _) in concurrent_fetcher(self.app, Name.from_str("/"), name_at_repo, start_index, end_index, semaphore):
             b_array.extend(content)
 
       # After b_array is filled, sort out what to do with the data.
