@@ -10,7 +10,7 @@
 # @Pip-Library: https://pypi.org/project/ndn-hydra/
 # ----------------------------------------------------------
 
-import argparse
+from argparse import ArgumentParser
 import asyncio as aio
 import logging
 from typing import Dict
@@ -20,61 +20,76 @@ from ndn.app import NDNApp
 from ndn.encoding import Name
 from ndn_python_repo import SqliteStorage
 import sys, os
+from ndn.svs import SVSyncLogger
 from ndn_hydra.repo import *
 
 
 def process_cmd_opts():
-    """
-    Parse, process, and return cmd options.
-    """
-    def get_version() -> str:
-        try:
-            return "ndn-hydra " + pkg_resources.require("ndn-hydra")[0].version
-        except pkg_resources.DistributionNotFound:
-            return "ndn-hydra source, undetermined"
-
+    def interpret_version() -> None:
+        set = True if "-v" in sys.argv else False
+        if set and (len(sys.argv)-1 < 2):
+            try: print("ndn-hydra " + pkg_resources.require("ndn-hydra")[0].version)
+            except pkg_resources.DistributionNotFound: print("ndn-hydra source,undetermined")
+            sys.exit(0)
+    def interpret_help() -> None:
+        set = True if "-h" in sys.argv else False
+        if set:
+            if (len(sys.argv)-1 < 2):
+                print("usage: ndn-hydra-repo [-h] [-v] -rp REPO_PREFIX -n NODE_NAME -s SESSION_ID")
+                print("    ndn-hydra-repo: hosting a node for hydra, the NDN distributed repo.")
+                print("    ('python3 ./examples/repo.py' instead of 'ndn-hydra-repo' if from source.)")
+                print("")
+                print("* informational args:")
+                print("  -h, --help                       |   shows this help message and exits.")
+                print("  -v, --version                    |   shows the current version and exits.")
+                print("")
+                print("* required args:")
+                print("  -rp, --repoprefix REPO_PREFIX    |   repo (group) prefix. Example: \"/hydra\"")
+                print("  -n, --nodename NODE_NAME         |   node name. Example: \"node01\"")
+                print("  -s, --sessionid SESSION_ID       |   id of this session. Example: \"2c4f\"")
+                print("")
+                print("Thank you for using hydra.")
+            sys.exit(0)
     def process_prefix(input_string: str):
         if input_string[-1] == "/":
             input_string = input_string[:-1]
         if input_string[0] != "/":
             input_string = "/" + input_string
         return input_string
-
     def process_others(input_string: str):
         if input_string[-1] == "/":
             input_string = input_string[:-1]
         if input_string[0] == "/":
             input_string = input_string[1:]
         return input_string
-
     def parse_cmd_opts():
         # Command Line Parser
-        parser = argparse.ArgumentParser(add_help=False,description="ndn-hydra: Hydra, a distributed repo in NDN",epilog="Thank you for using Hydra.")
-        informationArgs = parser.add_argument_group("information arguments")
-        requiredArgs = parser.add_argument_group("required arguments")
-        optionalArgs = parser.add_argument_group("optional arguments")
+        parser = ArgumentParser(prog="ndn-hydra-repo",add_help=False,allow_abbrev=False)
 
         # Adding all Command Line Arguments
-        informationArgs.add_argument("-v","--version",action="version",version=get_version())
-        informationArgs.add_argument("-h","--help",action="help",help="show this help message and exit")
-        requiredArgs.add_argument("-rp","--repoprefix",action="store",dest="repo_prefix",required=True,help="repo (group) prefix. Example: \"/hydra\"")
-        requiredArgs.add_argument("-n","--nodename",action="store",dest="node_name",required=True,help="node name. Example: \"node01\"")
-        requiredArgs.add_argument("-s","--sessionid",action="store",dest="session_id",required=True,help="id of this session. Example: \"2c4f\"")
+        parser.add_argument("-h","--help",action="store_true",dest="help",default=False,required=False)
+        parser.add_argument("-v","--version",action="store_true",dest="version",default=False,required=False)
+        parser.add_argument("-rp","--repoprefix",action="store",dest="repo_prefix",required=True)
+        parser.add_argument("-n","--nodename",action="store",dest="node_name",required=True)
+        parser.add_argument("-s","--sessionid",action="store",dest="session_id",required=True)
+
+        # Interpret Informational Arguments
+        interpret_version()
+        interpret_help()
 
         # Getting all Arguments
         vars = parser.parse_args()
-        args = {}
 
         # Process args
+        args = {}
         args["repo_prefix"] = process_prefix(vars.repo_prefix)
         args["node_name"] = process_others(vars.node_name)
         args["session_id"] = process_others(vars.session_id)
         workpath = "{home}/.ndn/repo{repo_prefix}/{session_id}".format(home=os.path.expanduser("~"), repo_prefix=args["repo_prefix"], session_id=args["session_id"])
-        rgs["logging_path"] = "{workpath}/session.log".format(workpath=workpath)
+        args["logging_path"] = "{workpath}/session.log".format(workpath=workpath)
         args["data_storage_path"] = "{workpath}/data.db".format(workpath=workpath)
         args["global_view_path"] = "{workpath}/global_view.db".format(workpath=workpath)
         args["svs_storage_path"] = "{workpath}/svs.db".format(workpath=workpath)
-
         return args
 
     args = parse_cmd_opts()
@@ -94,7 +109,6 @@ class HydraSessionThread(Thread):
         self.config = config
 
     def run(self) -> None:
-        os.makedirs("{home}/.ndn/".format(home=os.path.expanduser("~")), exist_ok=True)
         if len(os.path.dirname(self.config['logging_path'])) > 0 and not os.path.exists(os.path.dirname(self.config['logging_path'])):
             try:
                 os.makedirs(os.path.dirname(self.config['logging_path']))
@@ -103,6 +117,8 @@ class HydraSessionThread(Thread):
             except FileExistsError:
                 pass
 
+        # logging
+        SVSyncLogger.config(False, None, logging.INFO)
         logging.basicConfig(level=logging.INFO,
                             format='%(created)f  %(levelname)-8s  %(message)s',
                             filename=self.config['logging_path'],
@@ -111,12 +127,12 @@ class HydraSessionThread(Thread):
         console.setLevel(logging.INFO)
         logging.getLogger().addHandler(console)
 
-
+        # loop + NDN
         loop = aio.new_event_loop()
         aio.set_event_loop(loop)
         app = NDNApp()
 
-        # data_storage = SqliteStorage(self.config['data_storage_path']+"abc.db")
+        # databases
         data_storage = SqliteStorage(self.config['data_storage_path'])
         global_view = GlobalView(self.config['global_view_path'])
         pb = PubSub(app)
@@ -130,14 +146,17 @@ class HydraSessionThread(Thread):
         delete_handle = DeleteCommandHandle(app, data_storage, pb, self.config, main_loop, global_view)
         query_handle = QueryHandle(app, global_view, self.config)
 
-        # start listening
-        aio.ensure_future(listen(Name.normalize(self.config['repo_prefix']), pb, insert_handle, delete_handle))
+        # Post-start
+        async def start_main_loop():
+            await listen(Name.normalize(self.config['repo_prefix']), pb, insert_handle, delete_handle)
+            await main_loop.start()
 
+        # start listening
         try:
-            app.run_forever(after_start=main_loop.start())
+            app.run_forever(after_start=start_main_loop())
         except FileNotFoundError:
             print('Error: could not connect to NFD.')
-
+            sys.exit()
 
 def main() -> int:
     default_config = {
